

FITSOpticalElement
===================================

.. currentmodule:: poppy.poppy_core

.. autoclass:: FITSOpticalElement
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~FITSOpticalElement.pupil_diam

   
   

   
   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: pupil_diam

   
   

   
   
   